#!/usr/bin/env python

import jppy
from optparse import OptionParser

parser = OptionParser()

(options, args) = parser.parse_args()

env = jppy.environment.Environment()
ab = env.addressBook

for filename in args:
    vcard = open(filename).read()

    # a very nasty hack to work around a bug in the vobject-python library
    out_vcard = []
    block = vcard.split("\n")
    n = 0
    while n < len(block): 
        print repr(block[n])
        if block[n].endswith("=\r"):
            out_vcard.append(block[n][:-2] + block[n+1])
            n = n + 1
        elif block[n].endswith("="):
            out_vcard.append(block[n][:-1] + block[n+1])
            n = n + 1
        else:
            out_vcard.append(block[n])
        n = n + 1
    vcard = "\n".join(out_vcard)

    print vcard
    
    for contact in ab.loadVCards(vcard):
        #ab.save(contact)
        print "Added %s" % contact
